API
===

Import trackc as::

    import trackc as tc

Tool
~~~~~

.. module:: trackc.tl
.. currentmodule:: trackc

.. autosummary::
   :toctree: api

   tl.GenomeRegion
   tl.RegionsCmat
   tl.extractContactRegions
   tl.extractCisContact

GrigSpec
~~~~~~~~~

.. autosummary::
   :toctree: api

   trackc.make_spec
   trackc.tenon

Plotting
~~~~~~~~~

.. module:: trackc.pl
.. currentmodule:: trackc

.. autosummary::
   :toctree: api

   pl.scale_track
   pl.multi_scale_track
   pl.bed_track
   pl.bw_track
   pl.bw_compartment
   pl.virtual4C
   pl.links_track
   pl.zoomin
   pl.mapc_markline
   pl.gene_track
   pl.getData2Map
   pl.mapC


Palettes
~~~~~~~

.. module:: trackc.pa
.. currentmodule:: trackc

.. autosummary::
   :toctree: api

   pa.fruitpunch
   pa.fruitpunch2
   pa.colorC
   pa.trackcl_9
   pa.trackcl_11
   pa.vega_10_trackc
   pa.default_20
   pa.zeileis_28
   pa.default_102
